==> prestashop_1.4.0.7.zip: prestashop/modules/dibs/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{dibs}prestashop>dibs_b508edd89d96e13df300b298143998d3'] = 'DIBS';
$_MODULE['<{dibs}prestashop>dibs_ef3a95ad5c00ef1b4d1d73d2b50bf54c'] = 'DIBS API de paiement';
$_MODULE['<{dibs}prestashop>dibs_9089b5cc02d13f0fa4c9b6d97861ea4f'] = 'Pour des raisons de sécurité, vous devez enregistrer les clefs numéro 1 et 2 utilisées par le controle MD de l\'API DIBS.';
$_MODULE['<{dibs}prestashop>dibs_a71f6529f183021aca50cf8dd3b92872'] = 'Vous devez enregistrer votre ID marchand pour utiliser l\'API de DIBS.';
$_MODULE['<{dibs}prestashop>dibs_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration modifié';
$_MODULE['<{dibs}prestashop>dibs_f4f70727dc34561dfde1a3c529b6205c'] = 'Configurations';
$_MODULE['<{dibs}prestashop>dibs_794b8837b6ee6ddc4301f557915f9486'] = 'Couleur du logo';
$_MODULE['<{dibs}prestashop>dibs_44e1ec6255a91754e4911b16b9fc4d22'] = 'La couleur basique du logo qui apparait sur la page de paiement';
$_MODULE['<{dibs}prestashop>dibs_765b8797a61e6d71133acf35dd0ca98f'] = 'id du Marchand';
$_MODULE['<{dibs}prestashop>dibs_b305acae66879c527cda4c4ded662585'] = 'Regarder l\'e-mail envoyé par DIBS';
$_MODULE['<{dibs}prestashop>dibs_310fc01b7a8c167aa514ccccc9e46e99'] = 'Clé de sécurité n°1';
$_MODULE['<{dibs}prestashop>dibs_247cc6885be1cb649d05acf81242cc35'] = 'Clé de sécurité n°2';
$_MODULE['<{dibs}prestashop>dibs_eccc618d6b2ca6c4479db14d9ab2b301'] = 'Ces clefs sont utilisées pour améliorer la sécurité';
$_MODULE['<{dibs}prestashop>dibs_fad8e2c009f82d777e3143342aa6b7e8'] = 'Pour récupérer ces clefs allez sur l\'interface d\'administration de DIBS et dans le menu Integration > MD5 keys. N\'oubliez pas de vérifier si le control MD5 est activé, sinon le module ne sera pas fonctionnel.';
$_MODULE['<{dibs}prestashop>dibs_f9986472f2190b1ec04c52dd1eca1af4'] = 'Utiliser le module de test de DIBS';
$_MODULE['<{dibs}prestashop>dibs_313ada9ae4162978238c99d505bb6870'] = 'Quand ce champ est déclaré, la transaction n\'est pas envoyée à l\'émetteur de la carte, mais est envoyé au module de test de DIBS.';
$_MODULE['<{dibs}prestashop>dibs_41f538d798be040c3710e4e128105ad2'] = 'Regarder aussi l\'étape 5 du guide en 10 étapes pour plus d\'informations.';
$_MODULE['<{dibs}prestashop>dibs_97e7c9a7d06eac006a28bf05467fcc8b'] = 'Lien';
$_MODULE['<{dibs}prestashop>dibs_5caf2f84c1d971f645728f50e76ef542'] = 'Lors de votre première intégration avec DIBS, vous n\'avez pas besoin d\'utiliser ce paramètre, puisque toute les transactions par défaut vont utiliser le système de test tant que l\'intégration du site n\'a pas été approuvée par DIBS. Si le système de test doit être utilisé plus tard, il peut être activé chez DIBS (contactez le support DIBS pour réactiver le mode de test sur votre boutique)';
$_MODULE['<{dibs}prestashop>dibs_58768109d694bef3c059544892118901'] = 'Couleur de Flexwin';
$_MODULE['<{dibs}prestashop>dibs_37b0d284e5d29973b385ca537272ec38'] = 'La couleur du thême de Flexwin';
$_MODULE['<{dibs}prestashop>dibs_2e2b79996d4fb73bff9b97725ddfbab8'] = 'Url d\'acceptation';
$_MODULE['<{dibs}prestashop>dibs_cd034d4f983db501f3a1893d6b290939'] = 'L\'url de la page qui sera appelé une fois le paiement accepté.';
$_MODULE['<{dibs}prestashop>dibs_fcb9c3f1b9731de08442d81583782db7'] = 'Url d\'annulation';
$_MODULE['<{dibs}prestashop>dibs_610d424aac114ec924b91ceee8119c63'] = 'L\'url de la page qui sera appelé si l\'utilisateur annule le paiement';
$_MODULE['<{dibs}prestashop>dibs_b17f3f4dcf653a5776792498a9b44d6a'] = 'Modifier les configurations';
$_MODULE['<{dibs}prestashop>dibs_b64af11b4f643164b0b418c716a6f7a0'] = 'Payer avec DIBS';
$_MODULE['<{dibs}prestashop>dibs_fda89beb6740540db1053016d96624c3'] = 'Logo de DIBS';
$_MODULE['<{dibs}prestashop>dibs_eeaf35c1eb180cc38a77b892a96d7ed3'] = 'Payer rapidement et de manière sécurisé avec DIBS';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Votre commande sur';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'est terminée. ';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Votre commande vous sera envoyée dès que possible. ';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Pour toute question ou pour de plus amples renseignements, merci de communiquer avec notre ';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'service client';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Nous avons remarqué un problème avec votre commande. Si vous pensez que c\'est une erreur, vous pouvez contacter notre';

==> prestashop_1.4.0.10.zip: prestashop/modules/dibs/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{dibs}prestashop>dibs_b508edd89d96e13df300b298143998d3'] = 'DIBS';
$_MODULE['<{dibs}prestashop>dibs_ef3a95ad5c00ef1b4d1d73d2b50bf54c'] = 'DIBS API de paiement';
$_MODULE['<{dibs}prestashop>dibs_9089b5cc02d13f0fa4c9b6d97861ea4f'] = 'Pour des raisons de sécurité, vous devez enregistrer les clefs numéro 1 et 2 utilisées par le controle MD de l\'API DIBS.';
$_MODULE['<{dibs}prestashop>dibs_a71f6529f183021aca50cf8dd3b92872'] = 'Vous devez enregistrer votre ID marchand pour utiliser l\'API de DIBS.';
$_MODULE['<{dibs}prestashop>dibs_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration modifié';
$_MODULE['<{dibs}prestashop>dibs_f4f70727dc34561dfde1a3c529b6205c'] = 'Configurations';
$_MODULE['<{dibs}prestashop>dibs_794b8837b6ee6ddc4301f557915f9486'] = 'Couleur du logo';
$_MODULE['<{dibs}prestashop>dibs_44e1ec6255a91754e4911b16b9fc4d22'] = 'La couleur basique du logo qui apparait sur la page de paiement';
$_MODULE['<{dibs}prestashop>dibs_765b8797a61e6d71133acf35dd0ca98f'] = 'id du Marchand';
$_MODULE['<{dibs}prestashop>dibs_b305acae66879c527cda4c4ded662585'] = 'Regarder l\'e-mail envoyé par DIBS';
$_MODULE['<{dibs}prestashop>dibs_310fc01b7a8c167aa514ccccc9e46e99'] = 'Clé de sécurité n°1';
$_MODULE['<{dibs}prestashop>dibs_247cc6885be1cb649d05acf81242cc35'] = 'Clé de sécurité n°2';
$_MODULE['<{dibs}prestashop>dibs_c7138fc31d63f966e368147a0cd4e55d'] = 'Ces clefs sont utilisées pour améliorer la sécurité.';
$_MODULE['<{dibs}prestashop>dibs_3c39a3f9926600246193a5d1c515e898'] = 'Afin de récupérer ces clefs, rendez-vous sur l\'interface d\'administration de DIBS, dans le menu \"Integration\" > \"MD5 keys\". N\'oubliez pas de vérifier si le contrôle MD5 est activé, auquel cas le module ne sera pas opérationnel.';
$_MODULE['<{dibs}prestashop>dibs_f9986472f2190b1ec04c52dd1eca1af4'] = 'Utiliser le module de test de DIBS';
$_MODULE['<{dibs}prestashop>dibs_313ada9ae4162978238c99d505bb6870'] = 'Quand ce champ est déclaré, la transaction n\'est pas envoyée à l\'émetteur de la carte, mais est envoyé au module de test de DIBS.';
$_MODULE['<{dibs}prestashop>dibs_41f538d798be040c3710e4e128105ad2'] = 'Regarder aussi l\'étape 5 du guide en 10 étapes pour plus d\'informations.';
$_MODULE['<{dibs}prestashop>dibs_97e7c9a7d06eac006a28bf05467fcc8b'] = 'Lien';
$_MODULE['<{dibs}prestashop>dibs_5caf2f84c1d971f645728f50e76ef542'] = 'Lors de votre première intégration avec DIBS, vous n\'avez pas besoin d\'utiliser ce paramètre, puisque toute les transactions par défaut vont utiliser le système de test tant que l\'intégration du site n\'a pas été approuvée par DIBS. Si le système de test doit être utilisé plus tard, il peut être activé chez DIBS (contactez le support DIBS pour réactiver le mode de test sur votre boutique)';
$_MODULE['<{dibs}prestashop>dibs_58768109d694bef3c059544892118901'] = 'Couleur de Flexwin';
$_MODULE['<{dibs}prestashop>dibs_37b0d284e5d29973b385ca537272ec38'] = 'La couleur du thême de Flexwin';
$_MODULE['<{dibs}prestashop>dibs_2e2b79996d4fb73bff9b97725ddfbab8'] = 'Url d\'acceptation';
$_MODULE['<{dibs}prestashop>dibs_cd034d4f983db501f3a1893d6b290939'] = 'L\'url de la page qui sera appelé une fois le paiement accepté.';
$_MODULE['<{dibs}prestashop>dibs_fcb9c3f1b9731de08442d81583782db7'] = 'Url d\'annulation';
$_MODULE['<{dibs}prestashop>dibs_610d424aac114ec924b91ceee8119c63'] = 'L\'url de la page qui sera appelé si l\'utilisateur annule le paiement';
$_MODULE['<{dibs}prestashop>dibs_b17f3f4dcf653a5776792498a9b44d6a'] = 'Modifier les configurations';
$_MODULE['<{dibs}prestashop>dibs_b64af11b4f643164b0b418c716a6f7a0'] = 'Payer avec DIBS';
$_MODULE['<{dibs}prestashop>dibs_fda89beb6740540db1053016d96624c3'] = 'Logo de DIBS';
$_MODULE['<{dibs}prestashop>dibs_eeaf35c1eb180cc38a77b892a96d7ed3'] = 'Payer rapidement et de manière sécurisé avec DIBS';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Votre commande sur';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'est terminée. ';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Votre commande vous sera envoyée dès que possible. ';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Pour toute question ou pour de plus amples renseignements, merci de communiquer avec notre ';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'service client';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Nous avons remarqué un problème avec votre commande. Si vous pensez que c\'est une erreur, vous pouvez contacter notre';
